@@ -33,7 +33,7 @@ public:
 class TeXFont_TFM : public TeXFont
 {
 public:
-    TeXFont_TFM(TeXFontDefinition *parent);
+    explicit TeXFont_TFM(TeXFontDefinition *parent);
     ~TeXFont_TFM() override;
 
     glyph *getGlyph(quint16 character, bool generateCharacterPixmap = false, const QColor &color = Qt::black) override;
