@@ -767,7 +767,7 @@ void PDFGenerator::loadPages(QVector<Okular::Page *> &pagesVector, int rotation,
 #endif
             if (!okularFormFields.isEmpty())
                 page->setFormFields(okularFormFields);
-                //        kWarning(PDFDebug).nospace() << page->width() << "x" << page->height();
+                //        qWarning(PDFDebug).nospace() << page->width() << "x" << page->height();
 
 #ifdef PDFGENERATOR_DEBUG
             qCDebug(OkularPdfDebug) << "load page" << i << "with rotation" << rotation << "and orientation" << orientation;
@@ -1212,7 +1212,7 @@ void PDFGenerator::resolveMediaLinkReferences(Okular::Page *page)
 }
 
 struct TextExtractionPayload {
-    TextExtractionPayload(Okular::TextRequest *r)
+    explicit TextExtractionPayload(Okular::TextRequest *r)
         : request(r)
     {
     }
@@ -1463,6 +1463,12 @@ QVariant PDFGenerator::metaData(const QString &key, const QVariant &option) cons
         } else {
             return i18n("Using Poppler %1\n\nBuilt against Poppler %2", Poppler::Version::string(), POPPLER_VERSION);
         }
+    } else if (key == QLatin1String("ShowStampsWarning")) {
+#ifdef HAVE_POPPLER_21_10
+        return QStringLiteral("no");
+#else
+        return QStringLiteral("yes");
+#endif
     }
     return QVariant();
 }
@@ -1571,7 +1577,7 @@ bool PDFGenerator::exportTo(const QString &fileName, const Okular::ExportFormat
 
 inline void append(Okular::TextPage *ktp, const QString &s, double l, double b, double r, double t)
 {
-    //    kWarning(PDFDebug).nospace() << "text: " << s << " at (" << l << "," << t << ")x(" << r <<","<<b<<")";
+    //    qWarning(PDFDebug).nospace() << "text: " << s << " at (" << l << "," << t << ")x(" << r <<","<<b<<")";
     ktp->append(s, new Okular::NormalizedRect(l, t, r, b));
 }
 
