@@ -114,7 +114,7 @@ class PresentationToolBar : public QToolBar
     Q_OBJECT
 
 public:
-    PresentationToolBar(QWidget *parent = Q_NULLPTR)
+    explicit PresentationToolBar(QWidget *parent = Q_NULLPTR)
         : QToolBar(parent)
     {
     }
@@ -156,7 +156,6 @@ PresentationWidget::PresentationWidget(QWidget *parent, Okular::Document *doc, D
     , m_goToPreviousPageOnRelease(false)
     , m_goToNextPageOnRelease(false)
 {
-    Q_UNUSED(parent)
     setAttribute(Qt::WA_DeleteOnClose);
     setAttribute(Qt::WA_OpaquePaintEvent);
     setObjectName(QStringLiteral("presentationWidget"));
